@@ -113,7 +113,7 @@ class ExplorerSearchStackPageSearchGlobal(ExplorerSearchStackPage):
                     try:
                         results = future.result()
                     except Exception as exc:
-                        GLib.idle_add(complete_server, None, server_data, message=log_error_traceback(exc))
+                        GLib.idle_add(complete_server, None, server_data, log_error_traceback(exc))
                     else:
                         GLib.idle_add(complete_server, results, server_data)
 
