@@ -13,7 +13,7 @@ from pathlib import Path
 import shutil
 import time
 
-from modern_colorthief import get_palette
+from colorthief import ColorThief
 from PIL import Image
 from PIL import ImageFilter
 from PIL import ImageStat
@@ -24,6 +24,7 @@ from komikku.models.database import create_db_connection
 from komikku.models.database import insert_row
 from komikku.models.database import update_row
 from komikku.models.database import update_rows
+from komikku.servers import ServerDummy
 from komikku.servers.utils import get_server_class_name_by_id
 from komikku.servers.utils import get_server_dir_name_by_id
 from komikku.servers.utils import get_server_module_name_by_id
@@ -139,7 +140,7 @@ class Manga:
                 if '@define-color' not in data:
                     return data
 
-        palette = get_palette(cover_path, color_count=2)
+        palette = ColorThief(cover_path).get_palette(color_count=2, quality=1)[:2]
         if len(palette) != 2:
             # Single color image?
             return None
@@ -324,8 +325,12 @@ class Manga:
     @property
     def server(self):
         if self._server is None:
-            module = importlib.import_module('.' + self.module_name, package='komikku.servers')
-            self._server = getattr(module, self.class_name)()
+            try:
+                module = importlib.import_module('.' + self.module_name, package='komikku.servers')
+                self._server = getattr(module, self.class_name)()
+            except Exception:
+                logger.info('Failed to import server: %s', self.class_name)
+                self._server = ServerDummy(self.server_id)
 
         return self._server
 
