@@ -1,5 +1,5 @@
-# Copyright (C) 2019-2024 Valéry Febvre
-# SPDX-License-Identifier: GPL-3.0-only or GPL-3.0-or-later
+# SPDX-FileCopyrightText: 2019-2025 Valéry Febvre
+# SPDX-License-Identifier: GPL-3.0-or-later
 # Author: Valéry Febvre <vfebvre@easter-eggs.com>
 
 import datetime
@@ -23,14 +23,55 @@ from bs4 import BeautifulSoup
 from bs4 import NavigableString
 import dateparser
 import emoji
+from gi.repository import Gio
 from PIL import Image
+from PIL import ImageDraw
+from PIL import ImageFont
 import requests
 
+from komikku.consts import USER_AGENT
 from komikku.servers.loader import ServerFinder
+from komikku.utils import get_cached_logos_dir
 
 logger = logging.getLogger(__name__)
 
 
+class TextImage:
+    def __init__(self, text, width=1500, height=2126, bg_color='#fff', fg_color='#000', font_size=64, format='webp'):
+        self.format = format
+        self.image = Image.new('RGB', (width, height), bg_color)
+
+        if text is None:
+            text = ''
+
+        rfont = Gio.resources_lookup_data('/info/febvre/Komikku/text-image.otf', Gio.ResourceLookupFlags.NONE)
+        font = ImageFont.truetype(BytesIO(rfont.get_data()), font_size)
+
+        draw = ImageDraw.Draw(self.image)
+        if '\n' in text:
+            left, top, right, bottom = draw.multiline_textbbox((0, 0), text, font, font_size=font_size)
+        else:
+            left, top, right, bottom = draw.textbbox((0, 0), text, font, font_size=font_size)
+
+        text_width = right - left
+        text_height = bottom - top
+        text_coord = ((width - text_width) // 2, (height - text_height) // 2)
+
+        draw.multiline_text(text_coord, text, fill=fg_color, font=font, align='center')
+        del draw
+
+    @property
+    def content(self):
+        buf = BytesIO()
+        self.image.save(buf, self.format.upper())
+
+        return buf.getvalue()
+
+    @property
+    def mime_type(self):
+        return f'image/{self.format}'
+
+
 def convert_date_string(date_string, format=None, languages=None):
     """
     Convert a date string into a date object
@@ -91,39 +132,6 @@ def convert_date_string(date_string, format=None, languages=None):
     return d.date() if d else None
 
 
-def convert_image(im, format='JPEG', ret_type='image'):
-    """
-    Convert an image to a specific format
-
-    :param im: A `PIL.Image.Image` or `bytes` object
-    :type im: PIL.Image.Image, bytes
-
-    :param format: Conversion formats documentation is available `here <https://pillow.readthedocs.io/en/stable/handbook/image-file-formats.html>`_
-    :type format: str
-
-    :param ret_type: image or bytes
-    :type ret_type: str
-
-    :return: An new image object in requested format
-    :rtype: PIL.Image.Image, bytes
-    """
-    if not isinstance(im, Image.Image):
-        im = Image.open(BytesIO(im))
-
-    io_buffer = BytesIO()
-    with im.convert('RGB') as im_rgb:
-        im_rgb.save(io_buffer, format)
-
-    im.close()
-
-    if ret_type == 'bytes':
-        return io_buffer.getvalue()
-
-    io_buffer.seek(0)
-
-    return Image.open(io_buffer)
-
-
 # https://github.com/italomaia/mangarock.py/blob/master/mangarock/mri_to_webp.py
 def convert_mri_data_to_webp_buffer(data):
     size_list = [0] * 4
@@ -253,7 +261,7 @@ def get_servers_list(include_disabled=False, order_by=('lang', 'name')):
                 continue
 
             if inspect.isclass(obj):
-                logo_path = os.path.join(os.path.dirname(os.path.abspath(module.__file__)), get_server_main_id_by_id(obj.id) + '.png')
+                logo_path = os.path.join(get_cached_logos_dir(), 'servers', get_server_main_id_by_id(obj.id) + '.png')
 
                 servers.append(dict(
                     id=obj.id,
@@ -263,6 +271,7 @@ def get_servers_list(include_disabled=False, order_by=('lang', 'name')):
                     is_nsfw=obj.is_nsfw,
                     is_nsfw_only=obj.is_nsfw_only,
                     logo_path=logo_path if os.path.exists(logo_path) else None,
+                    logo_url=obj.logo_url,
                     module=module,
                     class_name=get_server_class_name_by_id(obj.id),
                 ))
@@ -270,7 +279,7 @@ def get_servers_list(include_disabled=False, order_by=('lang', 'name')):
     return sorted(servers, key=itemgetter(*order_by))
 
 
-def get_servers_modules(reload=False):
+def get_servers_modules():
     def import_external_modules(servers_path, modules, modules_names, multi=False):
         if multi:
             servers_path = os.path.join(servers_path, 'multi')
@@ -289,8 +298,6 @@ def get_servers_modules(reload=False):
                 continue
 
             module = importlib.import_module(f'.{name}', package='komikku.servers.multi' if multi else 'komikku.servers')
-            if reload:
-                module = importlib.reload(module)
             modules.append(module)
             modules_names.append(module_name)
             count += 1
@@ -307,8 +314,6 @@ def get_servers_modules(reload=False):
                 continue
 
             module = importlib.import_module(module_name)
-            if reload:
-                module = importlib.reload(module)
             modules.append(module)
             modules_names.append(module_name)
             count += 1
@@ -336,23 +341,13 @@ def get_servers_modules(reload=False):
                     # Not very likely
                     continue
 
-                if reload:
-                    # Multi-servers must be imported first
-                    import_external_modules(servers_path, modules, modules_names, multi=True)
-
                 import_external_modules(servers_path, modules, modules_names, multi=False)
 
         elif not internal_done:
             # Import internal servers
             import komikku.servers
 
-            count = 0
-            if reload:
-                # Multi-servers must be imported first
-                import komikku.servers.multi
-                count += import_internal_modules(komikku.servers.multi, modules, modules_names)
-
-            count += import_internal_modules(komikku.servers, modules, modules_names)
+            count = import_internal_modules(komikku.servers, modules, modules_names)
 
             if count > 0:
                 internal_done = True
@@ -449,9 +444,6 @@ def search_duckduckgo(site, term, nb_pages=1):
     :return: A list of dictionaries (name, url)
     :rtype: list of dict
     """
-
-    from komikku.servers import USER_AGENT
-
     base_url = 'https://lite.duckduckgo.com'
 
     session = requests.Session()
